==> nextcloud-21.0.4.tgz: nextcloud/apps/updatenotification/l10n/fi.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} on saatavilla. Tarjolla on lisätietoja päivittämisestä.",
    "Channel updated" : "Päivityskanava päivitetty",
    "Web updater is disabled" : "Päivitys selaimen kautta on poissa käytöstä",
    "Update notifications" : "Päivitysilmoitukset",
    "The update server could not be reached since %d days to check for new updates." : "Päivityspalvelinta ei ole tavoitettu %d päivään; uusia päivityksiä ei voida tarkistaa.",
    "Please check the Nextcloud and server log files for errors." : "Tarkista Nextcloud- ja palvelinlokitiedostot virheiden osalta.",
    "Update to %1$s is available." : "Kohteen %1$s päivitys on saatavilla.",
    "Update for %1$s to version %2$s is available." : "Kohteen %1$s päivitys versioon %2$s on saatavilla.",
    "Update for {app} to version %s is available." : "Sovelluksen {app} päivitys versioon %s on saatavilla.",
    "Update notification" : "Päivitysilmoitus",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Näyttää Nextcloudin päivitysilmoitukset ja tarjoaa SSO:n (Single Sign-On) päivittäjälle.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Käyttämäsi versio ei ole enää tuettu. Varmista, että päivität tuettuun versioon mahdollisimman pian.",
    "Apps missing compatible version" : "Sovellukset, joista ei ole yhteensopivaa versiota",
    "View in store" : "Näytä kaupassa",
    "Apps with compatible version" : "Sovellukset, joista on yhteensopiva versio",
    "Open updater" : "Avaa päivittäjä",
    "Download now" : "Lataa heti",
    "Please use the command line updater to update." : "Käytä komentorivipäivitintä päivittääksesi.",
    "What's new?" : "Mitä uutta?",
    "The update check is not yet finished. Please refresh the page." : "Päivitystarkistus ei ole vielä valmis. Päivitä sivu.",
    "Your version is up to date." : "Versiosi on ajan tasalla.",
    "A non-default update server is in use to be checked for updates:" : "Käytössä on muu kuin oletusarvoinen päivityspalvelin, jota käytetään päivitysten tarkistamiseen:",
    "Update channel:" : "Päivityskanava:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Voit aina päivittää uudempaan versioon, mutta et voi palata aikaisempaan vakaaseen versioon.",
    "Notify members of the following groups about available updates:" : "Ilmoita seuraavien ryhmien jäsenille saatavilla olevista päivityksistä:",
    "Only notifications for app updates are available." : "Vain ilmoitukset sovelluspäivityksistä on saatavilla.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Valittu päivityskanava tekee palvelimen omat ilmoitukset tarpeettomiksi.",
    "The selected update channel does not support updates of the server." : "Valittu päivityskanava ei tue palvelimen päivityksiä.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Uusi versio on saatavilla: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Huomaa, että uuden julkaisun jälkeen päivitys näkyy vasta ensimmäisen pienemmän julkaisun jälkeen tai myöhemmin. Julkaisemme uusia versioita käyttäjillemme ajallisesti hajautetusti, ja joskus jätämme jonkin version väliin, jos ongelmia ilmenee. Lisätietoja päivityksistä ja julkaisukanavista osoitteessa {link}",
    "Checked on {lastCheckedDate}" : "Tarkistettu {lastCheckedDate}",
    "Checking apps for compatible versions" : "Tarkistetaan sovellusten yhteensopivat versiot ",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Varmista, ettei config.php-tiedosto aseta valintaa <samp>appstoreenabled</samp> arvoon false.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Kaikista</strong> sovelluksista on saatavilla yhteensopiva versio tämän Nextcloudin version kanssa.",
    "View changelog" : "Näytä muutosloki",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Yrityskäyttöön. Tarjoaa aina viimeisimmän korjaustason, mutta ei päivitä välittömästi seuraavaan pääversioon. Päivitys tapahtuu, kun Nextcloud GmbH on tehnyt lisävahvistuksia ja -testejä laajamittaisia ja kriittisiä käyttöönottoja varten. Tämä kanava on vain sopimusasiakkaiden käytettävissä, ja se tarjoaa Nextcloud Enterprise -paketin.",
    "Stable" : "Vakaa",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Viimeisin vakaa versio. Sopii säännölliseen käyttöön ja päivittyy aina uusimpaan pääversioon.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Esijulkaisuversio uusien toimintojen testaukseen, ei tuotantoympäristöille.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n:lle</strong> sovellukselle ei ole yhteensopivaa versiota tämän Nextcloud-version kanssa","<strong>%n:lle</strong> sovellukselle ei ole yhteensopivaa versiota tämän Nextcloud-version kanssa"],
    "Apps missing updates" : "Sovellukset, joilta puuttuvat päivitykset",
    "Apps with available updates" : "Sovellukset, joihin saatavilla päivityksiä",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Huomioi, että uuden julkaisun jälkeen voi mennä jonkin aikaa ennenkuin se näkyy täällä. Julkaisemme uusia versioita käyttäjillemme ajoittain, ja joskus jätämme jonkin version väliin, jos havaitsemme ongelmia.",
    "Only notification for app updates are available." : "Sovelluspäivityksiin on saatavilla vain huomautuksia.",
    "Checking apps for compatible updates" : "Tarkistetaan sovellusten yhteensopivat päivitykset ",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Yhteyttä sovelluskauppaan ei voitu muodostaa tai sovelluskauppa ei ilmoittanut päivityksistä. Etsi päivityksiä manuaalisesti tai varmista, että palvelimellasi on yhteys internetiin ja se voi yhdistää sovelluskauppaan.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Kaikilla</strong> sovelluksilla on päivitys tähän versioon saatavilla",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> sovelluksella ei ole päivitystä tähän versioon saatavilla","<strong>%n</strong> sovelluksella ei ole päivitystä tähän versioon saatavilla"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/updatenotification/l10n/fi.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} on saatavilla. Tarjolla on lisätietoja päivittämisestä.",
    "Channel updated" : "Päivityskanava päivitetty",
    "Web updater is disabled" : "Päivitys selaimen kautta on poissa käytöstä",
    "Update notifications" : "Päivitysilmoitukset",
    "The update server could not be reached since %d days to check for new updates." : "Päivityspalvelinta ei ole tavoitettu %d päivään; uusia päivityksiä ei voida tarkistaa.",
    "Please check the Nextcloud and server log files for errors." : "Tarkista Nextcloud- ja palvelinlokitiedostot virheiden osalta.",
    "Update to %1$s is available." : "Kohteen %1$s päivitys on saatavilla.",
    "Update for %1$s to version %2$s is available." : "Kohteen %1$s päivitys versioon %2$s on saatavilla.",
    "Update for {app} to version %s is available." : "Sovelluksen {app} päivitys versioon %s on saatavilla.",
    "Update notification" : "Päivitysilmoitus",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Näyttää Nextcloudin päivitysilmoitukset ja tarjoaa SSO:n (Single Sign-On) päivittäjälle.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Käyttämäsi versio ei ole enää tuettu. Varmista, että päivität tuettuun versioon mahdollisimman pian.",
    "Apps missing compatible version" : "Sovellukset, joista ei ole yhteensopivaa versiota",
    "View in store" : "Näytä kaupassa",
    "Apps with compatible version" : "Sovellukset, joista on yhteensopiva versio",
    "Open updater" : "Avaa päivittäjä",
    "Download now" : "Lataa heti",
    "Please use the command line updater to update." : "Käytä komentorivipäivitintä päivittääksesi.",
    "What's new?" : "Mitä uutta?",
    "The update check is not yet finished. Please refresh the page." : "Päivitystarkistus ei ole vielä valmis. Päivitä sivu.",
    "Your version is up to date." : "Versiosi on ajan tasalla.",
    "A non-default update server is in use to be checked for updates:" : "Käytössä on muu kuin oletusarvoinen päivityspalvelin, jota käytetään päivitysten tarkistamiseen:",
    "Update channel:" : "Päivityskanava:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Voit aina päivittää uudempaan versioon, mutta et voi palata aikaisempaan vakaaseen versioon.",
    "Notify members of the following groups about available updates:" : "Ilmoita seuraavien ryhmien jäsenille saatavilla olevista päivityksistä:",
    "Only notifications for app updates are available." : "Vain ilmoitukset sovelluspäivityksistä on saatavilla.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Valittu päivityskanava tekee palvelimen omat ilmoitukset tarpeettomiksi.",
    "The selected update channel does not support updates of the server." : "Valittu päivityskanava ei tue palvelimen päivityksiä.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Uusi versio on saatavilla: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Huomaa, että uuden julkaisun jälkeen päivitys näkyy vasta ensimmäisen pienemmän julkaisun jälkeen tai myöhemmin. Julkaisemme uusia versioita käyttäjillemme ajallisesti hajautetusti, ja joskus jätämme jonkin version väliin, jos ongelmia ilmenee. Lisätietoja päivityksistä ja julkaisukanavista osoitteessa {link}",
    "Checked on {lastCheckedDate}" : "Tarkistettu {lastCheckedDate}",
    "Checking apps for compatible versions" : "Tarkistetaan sovellusten yhteensopivat versiot ",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Varmista, ettei config.php-tiedosto aseta valintaa <samp>appstoreenabled</samp> arvoon false.",
    "View changelog" : "Näytä muutosloki",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Yrityskäyttöön. Tarjoaa aina viimeisimmän korjaustason, mutta ei päivitä välittömästi seuraavaan pääversioon. Päivitys tapahtuu, kun Nextcloud GmbH on tehnyt lisävahvistuksia ja -testejä laajamittaisia ja kriittisiä käyttöönottoja varten. Tämä kanava on vain sopimusasiakkaiden käytettävissä, ja se tarjoaa Nextcloud Enterprise -paketin.",
    "Stable" : "Vakaa",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Viimeisin vakaa versio. Sopii säännölliseen käyttöön ja päivittyy aina uusimpaan pääversioon.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Esijulkaisuversio uusien toimintojen testaukseen, ei tuotantoympäristöille.",
    "Apps missing updates" : "Sovellukset, joilta puuttuvat päivitykset",
    "Apps with available updates" : "Sovellukset, joihin saatavilla päivityksiä",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Huomioi, että uuden julkaisun jälkeen voi mennä jonkin aikaa ennenkuin se näkyy täällä. Julkaisemme uusia versioita käyttäjillemme ajoittain, ja joskus jätämme jonkin version väliin, jos havaitsemme ongelmia.",
    "Only notification for app updates are available." : "Sovelluspäivityksiin on saatavilla vain huomautuksia.",
    "Checking apps for compatible updates" : "Tarkistetaan sovellusten yhteensopivat päivitykset ",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Yhteyttä sovelluskauppaan ei voitu muodostaa tai sovelluskauppa ei ilmoittanut päivityksistä. Etsi päivityksiä manuaalisesti tai varmista, että palvelimellasi on yhteys internetiin ja se voi yhdistää sovelluskauppaan.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Kaikilla</strong> sovelluksilla on päivitys tähän versioon saatavilla",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> sovelluksella ei ole päivitystä tähän versioon saatavilla","<strong>%n</strong> sovelluksella ei ole päivitystä tähän versioon saatavilla"],
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Kaikista</strong> sovelluksista on saatavilla yhteensopiva versio tämän Nextcloudin version kanssa.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n:lle</strong> sovellukselle ei ole yhteensopivaa versiota tämän Nextcloud-version kanssa","<strong>%n:lle</strong> sovellukselle ei ole yhteensopivaa versiota tämän Nextcloud-version kanssa"]
},
"nplurals=2; plural=(n != 1);");
